import gevent
import pandas as pd
from typing import Dict, List, Union
from gevent.pool import Pool
from ...crawl.settings import *
from ..utils import get_quote_id, requests_obj, parse_obj, to_numeric
from .config import *


class CommonFunc:
    def __int__(self):
        pass

    def get_common_func(self, stock_codes: Union[str, List[str]], single_func, **kwargs):
        if isinstance(stock_codes, str):
            return getattr(DataOne, f"{single_func}_data_one")(stock_codes, **kwargs)
        elif hasattr(stock_codes, '__iter__'):
            codes = list(stock_codes)
            return self.get_quote_multi_new(
                codes, single_func=single_func, **kwargs
            )
        raise TypeError('代码数据类型输入不正确！')

    def get_quote_multi_new(self,
                            codes: List[str],
                            beg: str = '19000101',
                            end: str = '20500101',
                            klt: int = 101,
                            fqt: int = 1,
                            report_class: str = None,
                            single_func: str = None,
                            **kwargs,
                            ) -> Dict[str, pd.DataFrame]:
        """
        获取多只股票、债券历史行情信息 或者实时行情
        """
        total = len(codes)
        pool = Pool(total)
        func = getattr(DataOne, f"{single_func}_data_one")
        coroutine_list = [pool.spawn(func, x, beg=beg, end=end, klt=klt, fqt=fqt,
                                     report_class=report_class, **kwargs) for x in codes]
        gevent.joinall(coroutine_list)
        df_value = [_.value for _ in coroutine_list]
        dfs = dict(zip(codes, df_value))
        return dfs


class DataOne:
    market_dict = {"1": "sh", "0": "sz", "116": "hk"}

    @staticmethod
    @to_numeric
    def get_stock_base_info_data_one(stock_codes: str, **kwargs) -> pd.DataFrame:
        use_code_id = get_quote_id(stock_codes)
        use_code_list = use_code_id.split(".")
        use_code = '.'.join([use_code_list[1], DataOne.market_dict[use_code_list[0]]])
        url = ''.join(stock_base_info_url)
        data = {"code": use_code}
        json_response = requests_obj.get(url, data).json()
        return parse_obj.parse_stock_base_info(json_response)

    @staticmethod
    @to_numeric
    def get_stock_real_time_sum_capital_data_one(code: str, **kwargs) -> pd.DataFrame:
        quote_id = get_quote_id(code)
        params = (
            ('secids', quote_id),
            ('fields',
             'f62,f184,f66,f69,f72,f75,f78,f81,f84,f87,f64,f65,f70,f71,f76,f77,f82,f83,f252,f253,f254,f255,f256,f278,f279,f280,f281,f282'),
        )
        url = ''.join(capital_flow_real_time_url_list)
        json_response = requests_obj.get(url, params).json()
        return parse_obj.parse_capital_flow_json(json_response)

    @staticmethod
    @to_numeric
    def get_stock_real_time_sector_capital_data_one(sector: str, **kwargs) -> pd.DataFrame:
        monitor_time = kwargs.get("monitor_time")
        params_base = {"po": "1", "pz": "500", "pn": "1", "np": "1", "fltt": "2", "invt": "2"}
        params_dict = sector_dict[monitor_time]
        fields_map = params_dict.pop("fields_map")
        drop_field = params_dict.pop("drop_field")
        params_base.update(params_dict)
        params_base.update(sector_dict2[sector])
        url = ''.join(sector_url_list)
        json_response = requests_obj.get(url, params_base).json()
        return parse_obj.parse_capital_flow_json(json_response, field_map=fields_map).drop(axis=1, columns=[drop_field])



import datetime
import copy
import pandas as pd
from ..utils import requests_obj
from .config import a_stock_list_url, a_stock_trade_date_url, a_stock_index_url, \
    stock_intl_index_url, index_stock_composition_url, stock_bonus_url, stock_repurchase_url
from ..common.explain_change import exchange_explain_new
from ...crawl.settings import *


class StockServices:
    def __init__(self, token, *args, **kwargs):
        self.token = token

    def common_func(self, params, item_url):
        copy_base_url_list = copy.deepcopy(base_url_list)
        copy_base_url_list.append(item_url)
        headers = {"token": self.token}
        r = requests_obj.get("".join(copy_base_url_list), data=params, headers=headers)
        if isinstance(r, dict):
            return r
        data_json = r.json()
        return data_json

    def stock_to_list_data(self, **kwargs):
        is_explain = kwargs.pop("is_explain", False)
        data_json = self.common_func(kwargs, a_stock_list_url)
        if data_json['data'] and isinstance(data_json['data'], list):
            df = pd.DataFrame(data_json['data'])
            return exchange_explain_new(df, is_explain)
        else:
            return data_json

    def stock_to_trade_date_list(self, **kwargs):
        """
        交易日历数据
        Parameters
        ----------
        kwargs

        Returns
        -------

        """
        is_explain = kwargs.pop("is_explain", False)
        data_json = self.common_func(kwargs, a_stock_trade_date_url)
        if data_json['data'] and isinstance(data_json['data'], list):
            df = pd.DataFrame(data_json['data'])
            return exchange_explain_new(df, is_explain)
        else:
            return data_json

    def stock_to_index_list(self, **kwargs):
        is_explain = kwargs.pop("is_explain", False)
        data_json = self.common_func(kwargs, a_stock_index_url)
        if data_json['data'] and isinstance(data_json['data'], list):
            df = pd.DataFrame(data_json['data'])
            return exchange_explain_new(df, is_explain)
        else:
            return data_json

    def stock_to_intl_index_list(self, **kwargs):
        is_explain = kwargs.pop("is_explain", False)
        data_json = self.common_func(kwargs, stock_intl_index_url)
        if data_json['data'] and isinstance(data_json['data'], list):
            df = pd.DataFrame(data_json['data'])
            return exchange_explain_new(df, is_explain)
        else:
            return data_json

    def stock_to_index_stock_composition(self, **kwargs):
        is_explain = kwargs.pop("is_explain", False)
        data_json = self.common_func(kwargs, index_stock_composition_url)
        if data_json['data'] and isinstance(data_json['data'], list):
            df = pd.DataFrame(data_json['data'])
            return exchange_explain_new(df, is_explain)
        else:
            return data_json

    def stock_to_stock_bonus(self, **kwargs):
        is_explain = kwargs.pop("is_explain", False)
        data_json = self.common_func(kwargs, stock_bonus_url)
        if data_json['data'] and isinstance(data_json['data'], list):
            df = pd.DataFrame(data_json['data'])
            return exchange_explain_new(df, is_explain)
        else:
            return data_json

    def stock_to_stock_repurchase(self, **kwargs):
        is_explain = kwargs.pop("is_explain", False)
        data_json = self.common_func(kwargs, stock_repurchase_url)
        if data_json['data'] and isinstance(data_json['data'], list):
            df = pd.DataFrame(data_json['data'])
            return exchange_explain_new(df, is_explain)
        else:
            return data_json



car_sales_url = "/car_sales/car_data"

car_sales_field_dict = {
    "rank_list": "排名",
    "car_series": "车系",
    "dealer_min_price": "经销商最低价格",
    "dealer_max_price": "经销商最高价格",
    "maker_min_price": "厂商最低价格",
    "maker_max_price": "厂商最高价格",
    "brand_name": "总品牌",
    "sub_brand_name": "子品牌",
    "sales_volume": "销量",
    "car_type": "汽车类型",
    "pub_date": "公布时间",
    "source": "数据源"
}


import datetime
import copy
import pandas as pd
from ..utils import requests_obj
from .config import car_sales_url, car_sales_field_dict
from ..common.explain_change import exchange_explain_new
from ...crawl.settings import *

car_type_list = {
    "1": "轿车",
    "2": "suv",
    "3": "mpv"
}

source_list = {
    "1": "太平洋汽车",
    "2": "懂车帝"
}


class CarServices:
    def __init__(self, token, *args, **kwargs):
        self.token = token

    def car_to_kline_data(self, **kwargs):
        is_explain = kwargs.pop("is_explain", False)
        copy_base_url_list = copy.deepcopy(base_url_list)
        copy_base_url_list.append(car_sales_url)
        headers = {"token": self.token}
        r = requests_obj.get("".join(copy_base_url_list), data=kwargs, headers=headers)
        if isinstance(r, dict):
            return r
        data_json = r.json()
        for item in data_json.get('data', []):
            item['car_type'] = car_type_list.get(item['car_type'], item['car_type'])
            item['source'] = source_list.get(item['source'], item['source'])
        df = pd.DataFrame(data_json['data'])
        return exchange_explain_new(df, is_explain)



import copy
import pandas as pd
from .config import pig_fcr_url, pig_fcr_field_dict
from ...crawl.settings import *
from ..utils import to_numeric, requests_obj, parse_obj
from ..common.explain_change import exchange_explain


@to_numeric
def get_pig_data_common(token: str, pig_url: str, field_dict: dict, start_date: str, end_date: str, limit: int) -> pd.DataFrame:
    """
    :param token:
    :param field_dict:
    :param pig_url:
    :param start_date:
    :param end_date: 字段对应关系
    :param limit:
    :return:
    """
    headers = {"token": token}
    copy_base_url_list = copy.deepcopy(base_url_list)
    copy_base_url_list.append(pig_url)
    data = {}
    if start_date:
        data["start_date"] = start_date
    if end_date:
        data['end_date'] = end_date
    if limit:
        data['limit'] = limit
    r = requests_obj.get("".join(copy_base_url_list), data=data, headers=headers)
    if isinstance(r, dict):
        return r
    data_json = r.json()
    df = parse_obj.parse_god_cup_json(data_json, field_dict)
    return df


def get_pig_fcr(token: str, start_date: str = None, end_date: str = None, limit: int = None, is_explain: bool = False) -> pd.DataFrame:
    """
    获取猪周期的历史猪肉价格和猪粮比
    :param token:
    :param end_date:
    :param start_date:
    :param limit:
    :return:
    """
    return exchange_explain(get_pig_data_common(token, pig_fcr_url, pig_fcr_field_dict, start_date, end_date,  limit), is_explain)



import requests
from random import choice
from sharetop.crawl.settings import *

class CustomException(BaseException):
    pass

class BaseRequest:
    def __init__(self, *args, **kwargs):
        pass

    def get(self, url, data, user_agent=False, headers={}, *args, **kwargs):
        if user_agent:
            headers = {
                'User-Agent': choice(user_agent_list)
            }
        try:
            if headers.get("token"):
                if len(headers.get("token")) != 16:
                    return {"msg": "token有误，请先确认token是否正确"}
            r = requests.get(url, data, headers=headers)
            r_code = r.status_code
            if r_code == 401:
                return {"msg": "您还没有权限，请先开通权限"}
            try:
                data_json = r.json()
            except:
                return r
            data = data_json.get("data", {})
            if isinstance(data, dict):
                description = data.get("description", "")
                if description and "Invalid token" in description:
                    return {"msg": "token有误，请先确认token是否正确"}
            return r
        except:
            raise CustomException("request error and contact author")

    def post(self, url, data, user_agent=False, headers=None, *args, **kwargs):
        if user_agent:
            headers = {
                'User-Agent': choice(user_agent_list)
            }
        try:
            return requests.post(url, data, headers=headers)
        except:
            raise "request error and contact author"




import pathlib

from setuptools import find_packages, setup

here = pathlib.Path(__file__).parent
# require = (here / "requirements.txt").read_text(encoding='utf-8').split()
require = ['requests', 'rich', 'jsonpath', 'pandas', 'tqdm', 'retry', 'gevent', 'py_mini_racer']
readme = (here / "README.md").read_text(encoding='utf-8')
about = {}
exec((here / 'sharetop' / '__version__.py').read_text(encoding='utf-8'), about)
setup(
    name=about['__title__'],
    version=about['__version__'],
    description=about['__description__'],
    long_description=readme,
    long_description_content_type="text/markdown",
    url=about['__url__'],
    author=about['__author__'],
    author_email=about['__author_email__'],
    license="MIT",
    platforms=['any'],
    keywords=about['__keywords__'],
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
    ],
    packages=find_packages(),
    install_requires=require,
    project_urls=about['__project_urls__'],
)



import pandas as pd
from lxml import etree
import re
from jsonpath import jsonpath
from typing import Any, Callable, Dict, List, TypeVar, Union
from .config import STOCK_BASE_INFO_DICT, CAPITAL_FLOW_DICT


class BaseParse:
    def __int__(self, *args, **kwargs):
        self.stock_base_info_dict = STOCK_BASE_INFO_DICT

    def parse_html(self, html):
        return etree.HTML(html)

    def parse_json(self, json_response, json_par='$..klines[:]'):
        json_r: List[str] = jsonpath(json_response, json_par)
        return json_r

    def parse_fund_json(self, text_response):
        results = re.findall('\[.*\]', text_response)
        json_data = eval(results[0])
        return json_data

    def parse_god_cup_json(self, data_json, country_field_dict):
        data = data_json['data']
        df = pd.DataFrame(data)
        df.rename(columns=country_field_dict, inplace=True)
        return df

    def parse_capital_flow_json(self, data_json, field_map=None):
        data = data_json['data']['diff']
        df = pd.DataFrame(data)
        if field_map:
            use_map = field_map
        else:
            use_map = CAPITAL_FLOW_DICT
        df.rename(columns=use_map, inplace=True)
        return df

    def parse_stock_base_info(self, base_data):
        status = base_data.get("status")
        if status and status == -1:
            return pd.DataFrame([base_data])
        jbzl = base_data['jbzl'][0]
        fxxg = base_data['fxxg'][0]
        fxxg = {k.lower(): v for k, v in fxxg.items()}
        jbzl = {k.lower(): v for k, v in jbzl.items()}
        secucode = jbzl['secucode']
        code, mk_code = secucode.split(".")
        name = jbzl['security_name_abbr']
        org_name = jbzl['org_name']
        org_name_en = jbzl['org_name_en']
        uscc = jbzl['reg_num']
        security_type = jbzl['security_type']
        trade_market = jbzl['trade_market']
        em_industry = jbzl['em2016']
        industrycsrc1 = jbzl['industrycsrc1']
        chairman = jbzl['chairman']
        legal_person = jbzl['legal_person']
        president = jbzl['president']
        secretary = jbzl['secretary']
        secpresent = jbzl['secpresent']
        reg_capital = jbzl['reg_capital']
        found_date = fxxg['found_date']
        listing_date = fxxg['listing_date']
        province = jbzl['province']
        city = ""
        introduction = jbzl['org_profile']
        business_scope = jbzl['business_scope']
        website = jbzl['org_web']
        org_tel = jbzl['org_tel']
        org_fax = jbzl['org_fax']
        email = jbzl['org_email']
        reg_address = jbzl['reg_address']
        office_address = jbzl['address']
        emp_num = jbzl['emp_num']
        manager_num = jbzl['tatolnumber']
        law_office = jbzl['law_firm']
        accounting_firm = jbzl['accountfirm_name']
        if "深交" in security_type:
            exchange_code = "SZSE"
        elif "上交" in security_type:
            exchange_code = "SSE"
        elif "北京证券" in security_type:
            exchange_code = "BSE"
        else:
            exchange_code = ""
        last_result = {
            "secucode": secucode, "code": code, "mk_code": mk_code, "name": name, "org_name": org_name,
            "org_name_en": org_name_en,
            "uscc": uscc, "security_type": security_type, "trade_market": trade_market, "em_industry": em_industry,
            "industrycsrc1": industrycsrc1,
            "chairman": chairman, "legal_person": legal_person, "president": president, "secretary": secretary,
            "secpresent": secpresent, "reg_capital": reg_capital,
            "found_date": found_date, "listing_date": listing_date, "province": province, "city": city,
            "introduction": introduction, "business_scope": business_scope,
            "website": website, "org_tel": org_tel, "org_fax": org_fax, "email": email, "reg_address": reg_address,
            "office_address": office_address, "emp_num": emp_num,
            "manager_num": manager_num, "law_office": law_office, "accounting_firm": accounting_firm,
            "exchange_code": exchange_code
        }
        last_result = {STOCK_BASE_INFO_DICT.get(k, ""): v for k, v in last_result.items()}
        return pd.DataFrame([last_result])



from pathlib import Path

HERE = Path(__file__).parent

# 债券基本信息表头
EASTMONEY_BOND_BASE_INFO_FIELDS = {
    'SECURITY_CODE': '债券代码',
    'SECURITY_NAME_ABBR': '债券名称',
    'CONVERT_STOCK_CODE': '正股代码',
    'SECURITY_SHORT_NAME': '正股名称',
    'RATING': '债券评级',
    'PUBLIC_START_DATE': '申购日期',
    'ACTUAL_ISSUE_SCALE': '发行规模(亿)',
    'ONLINE_GENERAL_LWR': '网上发行中签率(%)',
    'LISTING_DATE': '上市日期',
    'EXPIRE_DATE': '到期日期',
    'BOND_EXPIRE': '期限(年)',
    'INTEREST_RATE_EXPLAIN': '利率说明',
}

js_str = """
    function mcode(input) {  
                var keyStr = "ABCDEFGHIJKLMNOP" + "QRSTUVWXYZabcdef" + "ghijklmnopqrstuv"   + "wxyz0123456789+/" + "=";  
                var output = "";  
                var chr1, chr2, chr3 = "";  
                var enc1, enc2, enc3, enc4 = "";  
                var i = 0;  
                do {  
                    chr1 = input.charCodeAt(i++);  
                    chr2 = input.charCodeAt(i++);  
                    chr3 = input.charCodeAt(i++);  
                    enc1 = chr1 >> 2;  
                    enc2 = ((chr1 & 3) << 4) | (chr2 >> 4);  
                    enc3 = ((chr2 & 15) << 2) | (chr3 >> 6);  
                    enc4 = chr3 & 63;  
                    if (isNaN(chr2)) {  
                        enc3 = enc4 = 64;  
                    } else if (isNaN(chr3)) {  
                        enc4 = 64;  
                    }  
                    output = output + keyStr.charAt(enc1) + keyStr.charAt(enc2)  
                            + keyStr.charAt(enc3) + keyStr.charAt(enc4);  
                    chr1 = chr2 = chr3 = "";  
                    enc1 = enc2 = enc3 = enc4 = "";  
                } while (i < input.length);  

                return output;  
            }  
"""



import pandas as pd
from .config import country_base_url, country_field_dict
from ...crawl.settings import *
from ..utils import to_numeric, requests_obj, parse_obj
from ..common.explain_change import exchange_explain


@to_numeric
def get_country_list(token: str, limit: int = 100, is_explain: bool = False) -> pd.DataFrame:
    """
    国家基本信息列表
    :param token:
    :param limit:
    :return:
    """
    headers = {"token": token}
    base_url_list.append(country_base_url)
    data = {"limit": limit}
    r = requests_obj.get("".join(base_url_list), data=data, headers=headers)
    if isinstance(r, dict):
        return r
    data_json = r.json()
    df = parse_obj.parse_god_cup_json(data_json, country_field_dict)
    return exchange_explain(df, is_explain)



from .get_futures_info import (
    get_future_history_data,
    get_future_all_realtime_quotes,
    get_future_deal_detail
)

__all__ = [
    'get_future_all_realtime_quotes',
    'get_future_deal_detail',
    'get_future_history_data'
]



# import sharetop as sp

from sharetop import sp_prepare
token = "**"
sp_obj = sp_prepare.BasicTop(token)
r = sp_obj.common_exec_func("stock_to_list_data", {"limit": 10, "is_explain": True})
#
# print(r.to_dict("records"))


# r2 = sp_obj.common_exec_func("stock_to_list_data", {"limit": 10, "is_explain": False})

print(r)


import pkgutil
import six


class ModuleProxyCache(dict):
    def __missing__(self, key):
        if '.' not in key:
            return __import__(key)

        module_name, class_name = key.rsplit('.', 1)
        _module = __import__(module_name, {}, {}, [class_name])
        handler = getattr(_module, class_name)
        self[key] = handler

        return handler


def import_string(path):
    result = _cache[path]
    return result


def import_submodules(context, root_module, path):
    for loader, module_name, is_pkg in pkgutil.walk_packages(path, root_module + '.'):
        module = __import__(module_name, globals(), locals(), ['__name__'])
        for k, v in six.iteritems(vars(module)):
            if not k.startswith('_'):
                context[k] = v
        context[module_name] = module


_cache = ModuleProxyCache()

print("_cache===========", _cache)



import sharetop.core.bond as bond
import sharetop.core.fund as fund
import sharetop.core.futures as futures
import sharetop.core.stock as stock
import sharetop.core.country as country
import sharetop.core.oil as oil
import sharetop.core.pig as pig
import sharetop.core.capital_flow as capital_flow
import sharetop.core.ship as ship
import sharetop.core.index as index
import sharetop.core.prepare as sp_prepare


STOCK_BASE_INFO_DICT = {"code": '股票代码',
                        "mk_code": '市场代码',
                        "secucode": '唯一代码',
                        "name": '股票名称',
                        "org_name": '公司名称',
                        "org_name_en": '公司英文名称',
                        "org_code": '公司id',
                        "uscc": '统一社会信用代码',
                        "security_type": '证券类别',
                        "trade_market": '上市交易所',
                        "em_industry": '东财行业',
                        "industrycsrc1": '证监会行业',
                        "chairman": '董事长',
                        "legal_person": '法人代表',
                        "president": '总经理',
                        "secretary": '董秘',
                        "secpresent": '证券事务代表',
                        "reg_capital": '注册资本(万)',
                        "found_date": '公司成立日期',
                        "listing_date": '公司上市日期',
                        "province": '所在省份',
                        "city": '所在城市',
                        "introduction": '公司简介',
                        "business_scope": '经营范围',
                        "website": '公司主页',
                        "org_tel": '联系电话',
                        "org_fax": '联系传真',
                        "email": '电子邮件',
                        "reg_address": '注册地址',
                        "office_address": '办公地址',
                        "emp_num": '员工人数',
                        "manager_num": '管理人员人数',
                        "law_office": '律师事务所',
                        "accounting_firm": '会计师事务所',
                        "exchange_code": '交易所代码'}

CAPITAL_FLOW_DICT = {
    "f62": "今日主力净流入",
    "f64": "超大单流入",
    "f65": "超大单流出",
    "f66": "今日超大单净流入",
    "f69": "超大单净比",
    "f70": "大单流入",
    "f71": "大单流出",
    "f72": "今日大单净流入",
    "f75": "大单净比",
    "f76": "中单流入",
    "f77": "中单流出",
    "f78": "今日中单净流入",
    "f81": "中单净比",
    "f82": "小单流入",
    "f83": "小单流出",
    "f84": "今日小单净流入",
    "f87": "小单净比",
    "f184": "主力净比",
    "f278": "5日主力净流入",
    "f279": "5日超大单净流入",
    "f280": "5日大单净流入",
    "f281": "5日中单净流入",
    "f282": "5日小单净流入",
    "f252": "20日主力净流入",
    "f253": "20日超大单净流入",
    "f254": "20日大单净流入",
    "f255": "20日中单净流入",
    "f256": "20日小单净流入"
}


import pandas as pd
import copy
from .config import car_sales_url, car_sales_field_dict
from ...crawl.settings import *
from ..utils import to_numeric, requests_obj, parse_obj
from ..common.explain_change import exchange_explain

car_type_list = {
    "1": "轿车",
    "2": "suv",
    "3": "mpv"
}

source_list = {
    "1": "太平洋汽车",
    "2": "懂车帝"
}


@to_numeric
def get_car_data_common(token: str, car_url: str, field_dict: dict, car_type: str = None, pub_date: str = None,
                        source: str = None,
                        limit: int = None) -> pd.DataFrame:
    """
    :param token:
    :param field_dict: 字段对应关系
    :param car_url:  具体是石油数据url
    :param data_type: 1为国家数据 2为机构数据 4为大洲数据
    :param limit:
    :return:
    """
    copy_base_url_list = copy.deepcopy(base_url_list)
    copy_base_url_list.append(car_url)
    data = {"car_type": car_type, "pub_date": pub_date, "source": source, "limit": limit}
    headers = {"token": token}
    r = requests_obj.get("".join(copy_base_url_list), data=data, headers=headers)
    if isinstance(r, dict):
        return r
    data_json = r.json()
    for item in data_json.get('data', []):
        item['car_type'] = car_type_list.get(item['car_type'], item['car_type'])
        item['source'] = source_list.get(item['source'], item['source'])
    df = parse_obj.parse_god_cup_json(data_json, field_dict)
    return df


def get_car_sales(token: str, car_type: str = None, pub_date: str = None, source: str = None, limit: int = 100,
                  is_explain: bool = False) -> pd.DataFrame:
    """
    :param is_explain:
    :param car_type:
    :param pub_date:
    :param source:
    :param token:
    :param limit:
    :return:
    """
    return exchange_explain(get_car_data_common(token, car_sales_url, car_sales_field_dict, car_type, pub_date,
                                                source, limit),
                            is_explain)



"""
.. include:: ../README.md
"""
__docformat__ = "restructuredtext"

from sharetop.api import (
    bond,
    fund,
    futures,
    stock,
    country,
    pig,
    oil,
    capital_flow,
    ship,
    sp_prepare,
    index
)

__all__ = ['stock', 'fund', 'bond', 'futures', 'country', 'pig', 'oil', 'capital_flow', 'ship', 'sp_prepare', 'index']
